==> core-1.23.0-sources.jar: software/amazon/awscdk/core/INumberProducer.java <==
package software.amazon.awscdk.core;

/**
 * Interface for lazy number producers.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.21.2 (build 4370756)", date = "2020-02-07T03:00:47.236Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.INumberProducer")
@software.amazon.jsii.Jsii.Proxy(INumberProducer.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface INumberProducer extends software.amazon.jsii.JsiiSerializable {

    /**
     * Produce the number value.
     * <p>
     * @param context This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.Number produce(final software.amazon.awscdk.core.IResolveContext context);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.core.INumberProducer {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Produce the number value.
         * <p>
         * @param context This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public java.lang.Number produce(final software.amazon.awscdk.core.IResolveContext context) {
            return this.jsiiCall("produce", java.lang.Number.class, new Object[] { java.util.Objects.requireNonNull(context, "context is required") });
        }
    }
}

==> core-1.24.0-sources.jar: software/amazon/awscdk/core/INumberProducer.java <==
package software.amazon.awscdk.core;

/**
 * Interface for lazy number producers.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.22.0 (build 14afdde)", date = "2020-02-13T18:53:48.649Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.INumberProducer")
@software.amazon.jsii.Jsii.Proxy(INumberProducer.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface INumberProducer extends software.amazon.jsii.JsiiSerializable {

    /**
     * Produce the number value.
     * <p>
     * @param context This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.Number produce(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.IResolveContext context);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.core.INumberProducer {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Produce the number value.
         * <p>
         * @param context This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public @org.jetbrains.annotations.Nullable java.lang.Number produce(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.IResolveContext context) {
            return this.jsiiCall("produce", java.lang.Number.class, new Object[] { java.util.Objects.requireNonNull(context, "context is required") });
        }
    }
}
